﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Drawing;
using System.IO;
using System.Runtime.Serialization.Formatters.Binary;
using System.Runtime.InteropServices;
using System.ComponentModel;
using Microsoft.Win32;
using VidGrabNoForm;

namespace WPF_Quick_Start_Demo
{
    public partial class MainWindow : Window
    {
        VideoGrabberWPF Vg;

        public MainWindow()
        {
            InitializeComponent();
            Vg = new VideoGrabberWPF();
            Vg.OnFrameRefresh += new VideoGrabberWPF.OnFrameRefreshEventHandler(VideoGrabber_OnFrameRefresh);
        }

        void VideoGrabber_OnFrameRefresh(object sender, VideoGrabberWPF.TOnFrameRefreshEventArgs e)
        {
            image1.Source = e.BitmapSource;
        }

        private void image1_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            // this resizes the TVideoGrabber component to the size of the WPF control, disable this code if needed
            Vg.Width = image1.Width;
            Vg.Height = image1.Height;
        }

        private void StartRendering_Click(object sender, RoutedEventArgs e)
        {
            // starts the TVideoGrabber WPF rendering, the TVideoGrabber component is supposed to be already previewing or playing
            Vg.Start();
        }

        private void StopRendering_Click(object sender, RoutedEventArgs e)
        {
            // stops the TVideoGrabber WPF rendering, this does not stop the TVideoGrabber component that goes on previewing or playing in the background
            Vg.Stop();
        }

        private void OneShot_Click(object sender, RoutedEventArgs e)
        {
            // renders one frame. This stops the wpf rendering if Vg.Start() has been invoked previously. This does not stop the TVideoGrabber component that goes on previewing or playing in the background
            Vg.OneShot();
        }

        private void StartPreview_Click(object sender, RoutedEventArgs e)
        {
            Vg.VideoGrabber.VideoSource = TVideoSource.vs_ScreenRecording;
            Vg.VideoGrabber.StartPreview();
            Vg.FrameRate = 30.0; 
        }

        private void StopPreview_Click(object sender, RoutedEventArgs e)
        {
            Vg.VideoGrabber.StopPreview();
        }

        public const string AUDIO_CLIPS = "*.mp3;*.wav;*.wma;*.mid";
        public const string VIDEO_CLIPS = "*.mp*;*.vro;*.avi;*.asf;*.wmv;*.vob;*.avs;*.mov;*.divx;*.mp4;*.mts;*.3gp;*.swf;*.m2v;*.mkv;*.flv;*.wemb;*.ts;*.m4v;*.mp4v";
        public const string IMAGE_FILES = "*.jpg;*.jpeg;*.jpe;*.bmp;*.gif;*.png";
        public const string OPEN_MEDIA_FILES = "All media files|" + VIDEO_CLIPS + AUDIO_CLIPS + IMAGE_FILES
                        + "|Video clips|" + VIDEO_CLIPS
                        + "|Audio clips|" + AUDIO_CLIPS;
        public const string OPEN_MEDIA_FILES_EXTENDED = OPEN_MEDIA_FILES
                        + "|Image files|" + IMAGE_FILES;
        public const string OPEN_PICTURE_FILES = "Image files|*.bmp;*.jpg;*.gif;*.png;*.tif;*.tiff;*.wmf;*.emf;*.exf;*.jpe;*.jpeg";

        private void OpenClip_Click(object sender, RoutedEventArgs e)
        {
            OpenFileDialog fd = new OpenFileDialog();

            fd.Filter = OPEN_MEDIA_FILES_EXTENDED;
            if (fd.ShowDialog() == true)
            {
                Vg.FrameRate = 30.0;
                Vg.VideoGrabber.PlayerFileName = fd.FileName;
                Vg.VideoGrabber.OpenPlayer();
            }
        }

        private void CloseClip_Click(object sender, RoutedEventArgs e)
        {
            Vg.VideoGrabber.ClosePlayer();
        }


    }
}
